==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageTrueRangeIndicator = /*@__PURE__*/ (() => {
    class AverageTrueRangeIndicator extends StrategyBasedIndicator {
        get_yy() {
            return new AverageTrueRangeIndicatorStrategy();
        }
        get yy() {
            return this.get_yy();
        }
        get_zb() {
            return AverageTrueRangeIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
        get zj() {
            return typeGetValue(this.c(AverageTrueRangeIndicator.zk));
        }
        set zj(a) {
            this.h(AverageTrueRangeIndicator.zk, a);
        }
        y4() {
            return this.zj;
        }
        zd(a) {
            this.zj = a;
        }
    }
    AverageTrueRangeIndicator.$t = /*@__PURE__*/ markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zg(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/AverageTrueRangeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AverageTrueRangeIndicatorStrategy } from "./AverageTrueRangeIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AverageTrueRangeIndicator = /*@__PURE__*/ (() => {
    class AverageTrueRangeIndicator extends StrategyBasedIndicator {
        bj() {
            return new AverageTrueRangeIndicator();
        }
        get_abq() {
            return new AverageTrueRangeIndicatorStrategy();
        }
        get abq() {
            return this.get_abq();
        }
        get_ab3() {
            return AverageTrueRangeIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
        get acb() {
            return typeGetValue(this.c(AverageTrueRangeIndicator.acc));
        }
        set acb(a) {
            this.h(AverageTrueRangeIndicator.acc, a);
        }
        abw() {
            return this.acb;
        }
        ab5(a) {
            this.acb = a;
        }
    }
    AverageTrueRangeIndicator.$t = /*@__PURE__*/ markType(AverageTrueRangeIndicator, 'AverageTrueRangeIndicator', StrategyBasedIndicator.$);
    AverageTrueRangeIndicator.acc = /*@__PURE__*/ StrategyBasedIndicator.ab8(14, AverageTrueRangeIndicator.$);
    return AverageTrueRangeIndicator;
})();
